@@ -3,8 +3,6 @@ package MY::Class::Specio;
 use 5.006;
 use strict;
 use warnings;
-our @ISA;
-use Scalar::Util qw(looks_like_number);
 
 use Type::Tiny;
 
@@ -12,13 +10,10 @@ use MY::TypeLib::Specio;
 
 use Class::Tiny::ConstrainedAccessor
     medint => t('MediumInteger'),
-    med_with_default => t('MediumInteger'),
+    med_with_default => t('MediumIntegerInline'),   # for coverage
     lazy_default => t('MediumInteger'),
 ;
 
-BEGIN { undef @ISA; }   # So we're not a Mouse class
-    # See https://metacpan.org/release/Class-Tiny/source/lib/Class/Tiny.pm#L27
-
 # After using ConstrainedAccessor, we use this
 use Class::Tiny qw(medint regular), {
     med_with_default => 12,
